#ifndef GST_MEDIA_H
#define GST_MEDIA_H

#include <stdio.h>
#include <gst/gst.h> /* normally not needed */
#include <gst/rtp/gstrtcpbuffer.h>

#include "gstrtpsession.h"
#include "rtpsession.h"

#include "psa.h"

/*
 * See GstRtpNtpTimeSource enum in gstrtpsession.h
 */
#define NTP_SOURCE_TIME GST_RTP_NTP_TIME_SOURCE_UNIX

/*
 * RTCP Header
 */
typedef struct rtcp_header_t {
        unsigned int reports :  5;
        unsigned int padding :  1;
        unsigned int version :  2;
        unsigned int type    :  8;
        unsigned int len     : 16; /* little endian, use g_ntohs() */
} rtcp_header_t;

/* RTCP APP Header values
 *   version: 2    2
 *   padding: 1    0
 *   subtype: 5    8 (add 200 to have AVB code)
 *   type   : 8  204 (CC)
 *   len    :16    9 (does not include header)
 */
#define RTCP_APP_HEADER 0X88CC0009

/* for future use...
 *
 * RTCP AVB Header values
 *   version: 2    2
 *   padding: 1    0
 *   subtype: 5    0
 *   type   : 8  208 (D0)
 *   len    :16    9 (does not include header)
 */
#define RTCP_AVB_HEADER 0X80D00009

/*
 * RTCP AVB Packet
 */
typedef struct rtcp_avb_t {
	rtcp_header_t header;
        guint32 ssrc;
        gchar name[4];                  /* "PSA" */
        guint16 gm_time_base_indicator;	/* champ SHM PTP */
        guint16 gm_identity1;		/* 0 (not used) */
        guint64 gm_identity2;		/* champ gptp_grandmaster_id shm */
        guint64 stream_id;		/* à positionner au démarrage de gst */
        guint32 as_timestamp;		/* partie médiane du system_time SHM*/
        guint32 rtp_timestamp;		/* duplication du RTP */
} rtcp_avb_t;


#define MP3_CAPS "application/x-rtp,media=(string)audio,clock-rate=(int)44100,\
                  encoding-name=L16,encoding-params=(string)2,channels=(int)2,\
                  payload=(int)96"

GstStateChangeReturn psa_set_state_change(endpoint_t who,
					  GstStateChange transition);

const gchar *psa_state_change_get_name (GstStateChange transition);

void psa_gst_eos_event(endpoint_t who);

int psa_gst_send_init(char *snd_file, int mtu, char *ip_addr, int latency);

int psa_gst_send_play(void);

int psa_gst_send_pause(void);

int psa_gst_send_close(void);

int psa_gst_recv_init(char *ip_addr, char *caps);

int psa_gst_recv_play(void);

int psa_gst_recv_pause(void);

void psa_gst_recv_event(void);

int psa_gst_recv_close(void);

#endif
