/*
 * Copyright (c) 2013, Intel Corporation.
 *               2018, Kalyst <contact@kalyst.com>
 * ...
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>

#include "psa.h"
#include "gst_media.h"

#define MP3_FILE   "bob.mp3"
#define FRAME_SIZE 524
#define IP_DEFAULT  "192.168.1.161"
/* #define IP_DEFAULT  "172.20.8.64" */
#define LATENCY    0

static GstState state = GST_STATE_READY;

void sig_handler(int signum)
{
        fprintf(stderr, "talker: signal %d received...\n", signum);
        psa_gst_eos_event(TALKER);
}

void sig_handler_usr2(int signum)
{
        fprintf(stderr, "talker: signal %d received...\n", signum);
	if (state == GST_STATE_PLAYING) {
       	      fprintf(stderr, "talker sig: play to pause\n");
	      psa_set_state_change(TALKER, GST_STATE_CHANGE_PLAYING_TO_PAUSED);
	      state = GST_STATE_PAUSED;
	      return;
	}

	if (state == GST_STATE_PAUSED) {
       	      fprintf(stderr, "talker sig: pause to play\n");
	      psa_set_state_change(TALKER, GST_STATE_CHANGE_PAUSED_TO_PLAYING);
	      state = GST_STATE_PLAYING;
	      return;
	}
	return;
}

int main(int argc, char *argv[])
{
	char *ips;

	printf("talker: to pause or play, do \"kill -s 12 %d\"\n", getpid());

	gst_init(&argc, &argv);

	if (argc == 1)
		ips = IP_DEFAULT;
	else if (argc == 2)
		ips = argv[1];
	else {
		fprintf(stderr, "Erreur de paramétrage\n");
		exit(EXIT_FAILURE);
	}

        if (access(MP3_FILE, F_OK) == -1) {
                fprintf(stderr, "MP3 file (\"%s\") non présent\n", MP3_FILE);
		exit(EXIT_FAILURE);
	}

	signal(SIGINT, sig_handler);
	signal(SIGUSR2, sig_handler_usr2);

        printf("gst_send: start to %s...\n", ips);

        if (psa_gst_send_init(MP3_FILE, FRAME_SIZE, ips, LATENCY) == -1)  {
		fprintf(stderr, "Erreur d'initialisation\n");
		exit(1);
	}
	
	state = GST_STATE_PLAYING;
        psa_gst_send_play();
        
        psa_gst_send_close();
        return EXIT_SUCCESS;
}

